@@ -1,31 +1,26 @@
 summary.grain <- function(object, type='std', ...){
 
   type <- match.arg(type,c("std","cliques","rip","configurations"))
+    
+  cat("Independence network: Compiled:", object$isCompiled, "Propagated:", object$isPropagated, "\n")
 
-  cat("Nodes :", object$nodes,"\n")
-  isCompiled   <- object$compiled
-  isPropagated <- object$propagated
-
-  if (is.null(isPropagated))
-    isPropagated <- FALSE
-  else
-    isPropagated <- TRUE
-  cat("Compiled:", isCompiled, "Propagated:", isPropagated, "\n")
+  if (length(object$finding))
+    getFinding(object)
   
-  if (isCompiled){
+  cat(" Nodes :")
+  utils::str(object$nodes)
+  
+  if (object$isCompiled){
     rip <- object$rip
     cl  <- rip$clique
     se  <- rip$separators
     pa  <- rip$pa
     
-    #cat("\n")
     cl2 <- sapply(object$rip$cliques,length)
     cat(sprintf(" Number of cliques:              %4d \n",  length(cl2)))
     cat(sprintf(" Maximal clique size:            %4d \n",  max(cl2)))
     cat(sprintf(" Maximal state space in cliques: %4d \n",
         max(unlistPrim(lapply(object$potlist, length)))))
-
-    ##max(unlist(  sapply(object$potlist, "[", "ncells"))), "\n")
     
     if(length(e<-getFinding(object))){
       print(e)
@@ -48,6 +43,5 @@ summary.grain <- function(object, type='std', ...){
            })
   }
   return(invisible(object))
-
 }
 
